/**
 * @file
 * Defines Javascript behaviors for the textfield_confirm module.
 */

(function ($, Drupal) {

  "use strict";

  /**
   * Attaches the behavior to each input element.
   */
  Drupal.behaviors.textfieldConfirm = {
    attach: function (context, settings) {
      $(context).find('input.textfield-confirm-field').once('textfield-confirm').each(function () {
        Drupal.textfieldConfirm.processInput(this, settings.textfieldConfirm);
      });
    }
  };

  Drupal.textfieldConfirm = Drupal.textfieldConfirm || {};

  /**
   * Adds checking behavior to textfield input elements.
   */
  Drupal.textfieldConfirm.processInput = function (element, settings) {
    var $primary = $(element);

    var $secondary = $primary.parent().parent().find('input.textfield-confirm-confirm');
    var $helpText = $('<span class="textfield-confirm-help-text"></span>');
    $secondary.after($helpText);

    // Checks that the text fields are equal.
    function textfieldConfirmCheck() {
      // Verify that there is a value to check.
      if (!$primary.val()) {
        $helpText.hide();
        return;
      }

      var message = $primary.val() === $secondary.val() ? settings.success : settings.error;

      if ($helpText.html() != message) {
        $helpText.html(message);
      }

      $helpText.show();
    };

    // Monitor input events.
    $primary.on('input', textfieldConfirmCheck);
    $secondary.on('input', textfieldConfirmCheck);
  };

})(jQuery, Drupal);
